@@ -98,7 +98,7 @@ protected:
     void leaveEvent(QEvent*) override;
 
 protected:
-    const Segment *segmentAt(QPoint&) const; //FIXME const reference for a library others can use
+    const Segment *segmentAt(QPointF position) const; //FIXME const reference for a library others can use
     const Segment *rootSegment() const {
         return m_rootSegment;    ///never == 0
     }
@@ -111,7 +111,7 @@ private:
 
     const Folder *m_tree;
     const Segment   *m_focus;
-    QPoint           m_offset;
+    QPointF           m_offset;
     QTimer           m_timer;
     Map              m_map;
     Segment          *m_rootSegment;
